@@ -16,13 +16,13 @@ import re
 
 # Non-Standard Imports
 import pandas as pd
-from undetected_playwright.async_api import (
+from patchright.async_api import (
     async_playwright,
     Playwright,
     Page,
     Locator,
     expect,
-    Browser,
+    BrowserContext,
 )
 from pyvirtualdisplay import Display
 
@@ -107,7 +107,7 @@ async def wait_for_redirect(page: Page) -> None:
     :param page: The browser application
     """
     target_text: re.Pattern = re.compile(r"(Verify your identity|Dashboard)")
-    await expect(page.get_by_text(target_text).first).to_be_visible(timeout=TIMEOUT)
+    await expect(page.get_by_text(target_text)).not_to_have_count(0, timeout=TIMEOUT)
 
 
 @screenshot_on_timeout(f"{ERROR_DIR}/{datetime.now()}_{INSTITUTION}.png")
@@ -420,10 +420,11 @@ async def run(
     :return: A list of pandas dataframes of accounts info tables
     """
     # Instantiate browser
-    browser: Browser = await playwright.chromium.launch(
+    browser: BrowserContext = await playwright.chromium.launch_persistent_context(
+        user_data_dir=str(),
         channel="chrome",
         headless=False,
-        args=["--disable-blink-features=AutomationControlled"],
+        no_viewport=True,
     )
     page: Page = await browser.new_page()
 
