@@ -20,13 +20,13 @@ from random import randint, uniform
 
 # Non-Standard Imports
 import pandas as pd
-from undetected_playwright.async_api import (
+from patchright.async_api import (
     async_playwright,
     Playwright,
     Page,
     Locator,
     expect,
-    Browser,
+    BrowserContext,
     Download,
 )
 from pyvirtualdisplay import Display
@@ -248,7 +248,7 @@ async def get_account_types(page: Page) -> pd.DataFrame:
 
     log.info("Waiting for accounts tables to be visible...")
     account_label_locator: Locator = page.locator("a.account-holdings-link")
-    await expect(account_label_locator.first).to_be_visible(timeout=TIMEOUT)
+    await expect(account_label_locator).not_to_have_count(0, timeout=TIMEOUT)
 
     account_label_elements: List[Locator] = await account_label_locator.all()
 
@@ -419,10 +419,11 @@ async def run(
     :return: A list of pandas dataframes of accounts info tables
     """
     # Instantiate browser
-    browser: Browser = await playwright.chromium.launch(
+    browser: BrowserContext = await playwright.chromium.launch_persistent_context(
+        user_data_dir=str(),
         channel="chrome",
         headless=False,
-        args=["--disable-blink-features=AutomationControlled"],
+        no_viewport=True,
     )
     page: Page = await browser.new_page()
 
